;
;
; /////////////////////// PureLZMA test ///////////////////////
;
;
XIncludeFile "PureLZMA_Packer_DLL_Include.pb"
;
; Test file(s) :
TestFile$ = #PB_Compiler_Home + "PureBasic.exe"
;
Debug "----------- COMPRESS"
;
;
; Load original file into buffer
Stream = ReadFile(#PB_Any, TestFile$)
If Stream
  BufferLen = Lof(Stream)
  *Buffer =  AllocateMemory(BufferLen)
  If *Buffer = 0
    End
  EndIf
  ReadData(Stream, *Buffer, BufferLen)
  CloseFile(Stream)
Else
  Debug "Could not read original file"
  End
EndIf
;
;
; Compress buffer with LZMA
*OutBuffer = PureLZMA_DLL_Compress(*Buffer, @BufferLen)
Debug "PureLZMA_Compress : Returned value = " + Str(*OutBuffer)
Debug "PureLZMA_Compress : BufferLen = " + Str(BufferLen)
;
; PureLZMA_Compress() error codes :
;   -1  :  Memory allocation error
;   -2  :  Output buffer overflow or buffer not compressable
;   -3  :  Other compression error
; 
FreeMemory(*Buffer)
;
; Save compressed buffer in '.lzma' file
If *OutBuffer > 0
  Stream = CreateFile(#PB_Any, TestFile$ + ".lzma")
  If Stream
    WriteData(Stream, *OutBuffer, BufferLen)
    CloseFile(Stream)
  EndIf
  PureLZMA_DLL_FreeBuffer(*OutBuffer)
Else
  Debug "PureLZMA_Compress() failed, error = " + Str(*OutBuffer)
  End
EndIf
;
;
;
Debug "----------- UNCOMPRESS"
;
;
; Load compressed buffer from '.lzma' file
Stream = ReadFile(#PB_Any, TestFile$ + ".lzma")
If Stream
  BufferLen = Lof(Stream)
  *Buffer = AllocateMemory(BufferLen)
  If *Buffer = 0
    End
  EndIf
  ReadData(Stream, *Buffer, BufferLen)
  CloseFile(Stream)
Else
  Debug "Could not read compressed file"
  End
EndIf
;
;
; Unpack buffer with LZMA
*OutBuffer = PureLZMA_DLL_UnCompress(*Buffer, @BufferLen)
Debug "PureLZMA_UnCompress : Returned value = " + Str(*OutBuffer)
Debug "PureLZMA_UnCompress : BufferLen = " + Str(BufferLen)
;
; PureLZMA_UnCompress() error codes :
;    0    : Invalid data [not compressed by PureLZMA_Compress() ?]
;   -1    : Memory allocation error
;   -2    : Input buffer insufficient
;   -3,-4 : Other compression error
;
FreeMemory(*Buffer)
;
; Save unpacked buffer in '.lzma.unpacked' file
If *OutBuffer > 0
  Stream = CreateFile(#PB_Any, TestFile$ + ".lzma.unpacked")
  If Stream
    WriteData(Stream,*OutBuffer, BufferLen)
    CloseFile(Stream)
  EndIf
  PureLZMA_DLL_FreeBuffer(*OutBuffer)
Else
  Debug "PureLZMA_UnCompress() failed, error = " + Str(*OutBuffer)
  End
EndIf
;
; Compare original and '.lzma.unpacked' files !
;
Debug "----------- RESULT"
If MD5FileFingerprint(TestFile$) = MD5FileFingerprint(TestFile$ + ".lzma.unpacked")
  Debug "Compression with PureLZMA is Ok !"
Else
  Debug "PureLZMA failed !"
EndIf